
\name{drosophila2dmentrezg_dbconn}

\alias{drosophila2dmentrezg_dbconn}
\alias{drosophila2dmentrezg_dbfile}
\alias{drosophila2dmentrezg_dbschema}
\alias{drosophila2dmentrezg_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  drosophila2dmentrezg_dbconn()
  drosophila2dmentrezg_dbfile()
  drosophila2dmentrezg_dbschema(file="", show.indices=FALSE)
  drosophila2dmentrezg_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{drosophila2dmentrezg_dbconn} returns a connection object to the
  package annotation DB.  IMPORTANT: Don't call
  \code{\link[DBI:dbConnect]{dbDisconnect}} on the connection object
  returned by \code{drosophila2dmentrezg_dbconn} or you will break all the
  \code{\link[AnnotationDbi:AnnDbObj-class]{AnnDbObj}} objects defined
  in this package!

  \code{drosophila2dmentrezg_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{drosophila2dmentrezg_dbschema} prints the schema definition of the
  package annotation DB.

  \code{drosophila2dmentrezg_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{drosophila2dmentrezg_dbconn}: a DBIConnection object representing an
  open connection to the package annotation DB.

  \code{drosophila2dmentrezg_dbfile}: a character string with the path to the
  package annotation DB.

  \code{drosophila2dmentrezg_dbschema}: none (invisible \code{NULL}).

  \code{drosophila2dmentrezg_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI:dbSendQuery]{dbGetQuery}},
  \code{\link[DBI:dbConnect]{dbConnect}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbconn}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbfile}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbschema}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(drosophila2dmentrezg_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by drosophila2dmentrezg_dbconn() was
  ## created with:
  dbConnect(SQLite(), dbname=drosophila2dmentrezg_dbfile(), cache_size=64000,
  synchronous=0)

  drosophila2dmentrezg_dbschema()

  drosophila2dmentrezg_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

